@@ -10,9 +10,14 @@ from parse_qwantz.shape import get_shape, get_adjacent_pixels, get_box
 def get_thought(pixel: Pixel, image: SimpleImage) -> tuple[Box, list[Pixel]] | None:
     orig_pixels = get_shape(pixel, image)
     box = get_box(orig_pixels)
-    pixels: set[Pixel] = set(orig_pixels)
+    tripled_pixels: set[Pixel] = set(orig_pixels)
     for x, y in orig_pixels:
-        pixels.update({Pixel(x + 1, y), Pixel(x + 2, y)})
+        tripled_pixels.update({Pixel(x + 1, y), Pixel(x + 2, y)})
+    if is_thought(tripled_pixels, box, image) or is_thought(set(orig_pixels), box, image):
+        return box, sorted(orig_pixels)
+
+
+def is_thought(pixels: set[Pixel], box: Box, image: SimpleImage) -> bool:
     x_range = range(box.left + 1, box.right - 1)
     y_range = range(box.top + 1, box.bottom - 1)
     outside = set()
@@ -20,7 +25,6 @@ def get_thought(pixel: Pixel, image: SimpleImage) -> tuple[Box, list[Pixel]] | N
     outside.update(Pixel(box.right - 1, y) for y in y_range)
     outside.update((Pixel(x, box.top) for x in x_range))
     outside.update((Pixel(x, box.bottom - 1) for x in x_range))
-    non_empty_interior = False
     for x, y in product(x_range, y_range):
         if Pixel(x, y) in pixels:
             continue
@@ -37,7 +41,5 @@ def get_thought(pixel: Pixel, image: SimpleImage) -> tuple[Box, list[Pixel]] | N
             visited.add(current)
             to_visit.extend(get_adjacent_pixels(current))
         else:
-            non_empty_interior = True
-            break
-    if non_empty_interior:
-        return box, sorted(orig_pixels)
+            return True
+    return False
