@@ -22,6 +22,8 @@ WORD_SET = make_word_set(
 
 
 def disambiguate_hyphen(part1: str, part2: str):
+    if not (part1 and part2):
+        return False
     if part1[-1].islower() and part2[0].isupper():
         return True
     part1_lower = part1.lower()
